@@ -1,6 +1,9 @@
 """Асинхронная обёртка для Gismeteo API."""
 from __future__ import annotations
 
+from pygismeteo_base import models
+
+from . import types
 from ._gismeteo import Gismeteo
 
-__all__ = ("Gismeteo",)
+__all__ = ("Gismeteo", "models", "types")
