@@ -38,7 +38,8 @@ class Gismeteo:
             lang:
                 Язык. По умолчанию "ru".
             token:
-                X-Gismeteo-Token, если используемый по умолчанию перестал работать.
+                X-Gismeteo-Token,
+                если используемый по умолчанию перестал работать.
             session:
                 Экземпляр aiohttp.ClientSession.
                 По умолчанию для каждого запроса создаётся новый экземпляр.
