@@ -1,16 +1,17 @@
 from __future__ import annotations
 
-from typing import Any
-
 from aiohttp import ClientResponse, ClientSession
 from pygismeteo_base.http import BaseHttpClient
 from pygismeteo_base.types import Headers, Params
+from typing_extensions import Any
 
 
 class AiohttpClient(BaseHttpClient[ClientSession]):
     __slots__ = ()
 
-    async def get_response(self, endpoint: str, *, params: Params = None) -> Any:
+    async def get_response(
+        self, endpoint: str, *, params: Params = None
+    ) -> Any:
         response = await self._get_json(endpoint, params=params)
         return response["response"]
 
@@ -28,7 +29,12 @@ class AiohttpClient(BaseHttpClient[ClientSession]):
         return await response.json()
 
     async def _fetch(
-        self, endpoint: str, *, params: Params, headers: Headers, session: ClientSession
+        self,
+        endpoint: str,
+        *,
+        params: Params,
+        headers: Headers,
+        session: ClientSession,
     ) -> ClientResponse:
         async with session.get(
             f"https://api.gismeteo.net/v2/{endpoint}/",
